@@ -1,52 +1,42 @@
 /* vi: ts=8 sts=4 sw=4
- *
- * This file is part of the KDE project, module kdecore.
- * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
- * (C) 2007 Daniel M. Duley <daniel.duley@verizon.net>
- * with minor additions and based on ideas from
- * Torsten Rahn <torsten@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+
+    This file is part of the KDE project, module kdecore.
+    SPDX-FileCopyrightText: 2000 Geert Jansen <jansen@kde.org>
+    SPDX-FileCopyrightText: 2007 Daniel M. Duley <daniel.duley@verizon.net>
+
+    with minor additions and based on ideas from
+    SPDX-FileContributor: Torsten Rahn <torsten@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kiconeffect.h"
+#include "debug.h"
+
+#include <KColorScheme>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <kicontheme.h>
+
+#include <QDebug>
+#include <QPalette>
+#include <QSysInfo>
 
 #include <qplatformdefs.h>
+
 #include <math.h>
 
-#include <QSysInfo>
-#include <QDebug>
-#include <QPixmap>
-#include <QImage>
-#include <QColor>
-
-#include <kcolorscheme.h>
-#include <kicontheme.h>
-#include <kconfiggroup.h>
-
 class KIconEffectPrivate
 {
 public:
     // http://en.cppreference.com/w/cpp/language/zero_initialization
     KIconEffectPrivate()
-       : effect{{}}
-       , value{{}}
-       , color{{}}
-       , trans{{}}
-       , key{{}}
-       , color2{{}}
+        : effect{{}}
+        , value{{}}
+        , color{{}}
+        , trans{{}}
+        , key{{}}
+        , color2{{}}
     {
     }
 
@@ -65,17 +55,16 @@ KIconEffect::KIconEffect()
     init();
 }
 
-KIconEffect::~KIconEffect()
-{
-    delete d;
-}
+KIconEffect::~KIconEffect() = default;
 
 void KIconEffect::init()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    int i, j, effect = -1;
-    //FIXME: this really should be using KIconLoader::metaObject() to guarantee synchronization
+    int i;
+    int j;
+    int effect = -1;
+    // FIXME: this really should be using KIconLoader::metaObject() to guarantee synchronization
     // performance wise it's also practically guaranteed to be faster
     QStringList groups;
     groups += QStringLiteral("Desktop");
@@ -90,7 +79,8 @@ void KIconEffect::init()
     states += QStringLiteral("Active");
     states += QStringLiteral("Disabled");
 
-    QStringList::ConstIterator it, it2;
+    QStringList::ConstIterator it;
+    QStringList::ConstIterator it2;
     QString _togray(QStringLiteral("togray"));
     QString _colorize(QStringLiteral("colorize"));
     QString _desaturate(QStringLiteral("desaturate"));
@@ -142,15 +132,14 @@ void KIconEffect::init()
             d->color[i][j] = cg.readEntry(*it2 + QStringLiteral("Color"), QColor());
             d->color2[i][j] = cg.readEntry(*it2 + QStringLiteral("Color2"), QColor());
             d->trans[i][j] = cg.readEntry(*it2 + QStringLiteral("SemiTransparent"), false);
-
         }
     }
 }
 
 bool KIconEffect::hasEffect(int group, int state) const
 {
-    if (group < 0 || group >= KIconLoader::LastGroup ||
-            state < 0 || state >= KIconLoader::LastState) {
+    if (group < 0 || group >= KIconLoader::LastGroup //
+        || state < 0 || state >= KIconLoader::LastState) {
         return false;
     }
 
@@ -159,8 +148,8 @@ bool KIconEffect::hasEffect(int group, int state) const
 
 QString KIconEffect::fingerprint(int group, int state) const
 {
-    if (group < 0 || group >= KIconLoader::LastGroup ||
-            state < 0 || state >= KIconLoader::LastState) {
+    if (group < 0 || group >= KIconLoader::LastGroup //
+        || state < 0 || state >= KIconLoader::LastState) {
         return QString();
     }
 
@@ -171,8 +160,7 @@ QString KIconEffect::fingerprint(int group, int state) const
         cached += QLatin1Char(':');
         cached += tmp.setNum(d->value[group][state]);
         cached += QLatin1Char(':');
-        cached += d->trans[group][state] ? QLatin1String("trans")
-                  : QLatin1String("notrans");
+        cached += d->trans[group][state] ? QLatin1String("trans") : QLatin1String("notrans");
         if (d->effect[group][state] == Colorize || d->effect[group][state] == ToMonochrome) {
             cached += QLatin1Char(':');
             cached += d->color[group][state].name();
@@ -191,30 +179,26 @@ QString KIconEffect::fingerprint(int group, int state) const
 QImage KIconEffect::apply(const QImage &image, int group, int state) const
 {
     if (state >= KIconLoader::LastState) {
-        qWarning() << "Illegal icon state: " << state;
+        qCWarning(KICONTHEMES) << "Invalid icon state:" << state << ", should be one of KIconLoader::States";
         return image;
     }
     if (group >= KIconLoader::LastGroup) {
-        qWarning() << "Illegal icon group: " << group;
+        qCWarning(KICONTHEMES) << "Invalid icon group:" << group << ", should be one of KIconLoader::Group";
         return image;
     }
-    return apply(image, d->effect[group][state], d->value[group][state],
-                 d->color[group][state], d->color2[group][state], d->trans[group][state]);
+    return apply(image, d->effect[group][state], d->value[group][state], d->color[group][state], d->color2[group][state], d->trans[group][state]);
 }
 
-QImage KIconEffect::apply(const QImage &image, int effect, float value,
-                          const QColor &col, bool trans) const
+QImage KIconEffect::apply(const QImage &image, int effect, float value, const QColor &col, bool trans) const
 {
-    return apply(image, effect, value, col,
-                 KColorScheme(QPalette::Active, KColorScheme::View).background().color(), trans);
+    return apply(image, effect, value, col, KColorScheme(QPalette::Active, KColorScheme::View).background().color(), trans);
 }
 
-QImage KIconEffect::apply(const QImage &img, int effect, float value,
-                          const QColor &col, const QColor &col2, bool trans) const
+QImage KIconEffect::apply(const QImage &img, int effect, float value, const QColor &col, const QColor &col2, bool trans) const
 {
     QImage image = img;
     if (effect >= LastEffect) {
-        qWarning() << "Illegal icon effect: " << effect;
+        qCWarning(KICONTHEMES) << "Invalid icon effect:" << effect << ", should be one of KIconLoader::Effects";
         return image;
     }
     if (value > 1.0) {
@@ -248,31 +232,27 @@ QImage KIconEffect::apply(const QImage &img, int effect, float value,
 QPixmap KIconEffect::apply(const QPixmap &pixmap, int group, int state) const
 {
     if (state >= KIconLoader::LastState) {
-        qWarning() << "Illegal icon state: " << state;
+        qCWarning(KICONTHEMES) << "Invalid icon state:" << state << ", should be one of KIconLoader::States";
         return pixmap;
     }
     if (group >= KIconLoader::LastGroup) {
-        qWarning() << "Illegal icon group: " << group;
+        qCWarning(KICONTHEMES) << "Invalid icon group:" << group << ", should be one of KIconLoader::Group";
         return pixmap;
     }
-    return apply(pixmap, d->effect[group][state], d->value[group][state],
-                 d->color[group][state], d->color2[group][state], d->trans[group][state]);
+    return apply(pixmap, d->effect[group][state], d->value[group][state], d->color[group][state], d->color2[group][state], d->trans[group][state]);
 }
 
-QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
-                           const QColor &col, bool trans) const
+QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value, const QColor &col, bool trans) const
 {
-    return apply(pixmap, effect, value, col,
-                 KColorScheme(QPalette::Active, KColorScheme::View).background().color(), trans);
+    return apply(pixmap, effect, value, col, KColorScheme(QPalette::Active, KColorScheme::View).background().color(), trans);
 }
 
-QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
-                           const QColor &col, const QColor &col2, bool trans) const
+QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value, const QColor &col, const QColor &col2, bool trans) const
 {
     QPixmap result;
 
     if (effect >= LastEffect) {
-        qWarning() << "Illegal icon effect: " << effect;
+        qCWarning(KICONTHEMES) << "Invalid icon effect:" << effect << ", should be one of KIconLoader::Effects";
         return result;
     }
 
@@ -282,7 +262,7 @@ QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
     } else if (effect != NoEffect) {
         QImage tmpImg = pixmap.toImage();
         tmpImg = apply(tmpImg, effect, value, col, col2, trans);
-        result = QPixmap::fromImage(tmpImg);
+        result = QPixmap::fromImage(std::move(tmpImg));
     } else {
         result = pixmap;
     }
@@ -292,25 +272,26 @@ QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
 
 struct KIEImgEdit {
     QImage &img;
-    QVector <QRgb> colors;
-    unsigned int  *data;
-    unsigned int   pixels;
+    QList<QRgb> colors;
+    unsigned int *data;
+    unsigned int pixels;
 
-    KIEImgEdit(QImage &_img): img(_img)
+    KIEImgEdit(QImage &_img)
+        : img(_img)
     {
         if (img.depth() > 8) {
-            //Code using data and pixels assumes that the pixels are stored
-            //in 32bit values and that the image is not premultiplied
-            if ((img.format() != QImage::Format_ARGB32) &&
-                    (img.format() != QImage::Format_RGB32)) {
-                img = img.convertToFormat(QImage::Format_ARGB32);
+            // Code using data and pixels assumes that the pixels are stored
+            // in 32bit values and that the image is not premultiplied
+            if ((img.format() != QImage::Format_ARGB32) //
+                && (img.format() != QImage::Format_RGB32)) {
+                img.convertTo(QImage::Format_ARGB32);
             }
-            data   = (unsigned int *)img.bits();
+            data = (unsigned int *)img.bits();
             pixels = img.width() * img.height();
         } else {
             pixels = img.colorCount();
             colors = img.colorTable();
-            data   = (unsigned int *)colors.data();
+            data = (unsigned int *)colors.data();
         }
     }
 
@@ -368,8 +349,13 @@ void KIconEffect::colorize(QImage &img, const QColor &col, float value)
     QRgb *data = ii.data;
     QRgb *end = data + ii.pixels;
 
-    float rcol = col.red(), gcol = col.green(), bcol = col.blue();
-    unsigned char red, green, blue, gray;
+    float rcol = col.red();
+    float gcol = col.green();
+    float bcol = col.blue();
+    unsigned char red;
+    unsigned char green;
+    unsigned char blue;
+    unsigned char gray;
     unsigned char val = (unsigned char)(255.0 * value);
     while (data != end) {
         gray = qGray(*data);
@@ -395,8 +381,7 @@ void KIconEffect::colorize(QImage &img, const QColor &col, float value)
     }
 }
 
-void KIconEffect::toMonochrome(QImage &img, const QColor &black,
-                               const QColor &white, float value)
+void KIconEffect::toMonochrome(QImage &img, const QColor &black, const QColor &white, float value)
 {
     if (value == 0.0) {
         return;
@@ -407,7 +392,8 @@ void KIconEffect::toMonochrome(QImage &img, const QColor &black,
     QRgb *end = data + ii.pixels;
 
     // Step 1: determine the average brightness
-    double values = 0.0, sum = 0.0;
+    double values = 0.0;
+    double sum = 0.0;
     bool grayscale = true;
     while (data != end) {
         sum += qGray(*data) * qAlpha(*data) + 255 * (255 - qAlpha(*data));
@@ -421,36 +407,42 @@ void KIconEffect::toMonochrome(QImage &img, const QColor &black,
 
     // Step 2: Modify the image
     unsigned char val = (unsigned char)(255.0 * value);
-    int rw = white.red(), gw = white.green(), bw = white.blue();
-    int rb = black.red(), gb = black.green(), bb = black.blue();
+    int rw = white.red();
+    int gw = white.green();
+    int bw = white.blue();
+    int rb = black.red();
+    int gb = black.green();
+    int bb = black.blue();
     data = ii.data;
 
     if (grayscale) {
         while (data != end) {
-            if (qRed(*data) <= medium)
+            if (qRed(*data) <= medium) {
                 *data = qRgba((val * rb + (0xFF - val) * qRed(*data)) >> 8,
                               (val * gb + (0xFF - val) * qGreen(*data)) >> 8,
                               (val * bb + (0xFF - val) * qBlue(*data)) >> 8,
                               qAlpha(*data));
-            else
+            } else {
                 *data = qRgba((val * rw + (0xFF - val) * qRed(*data)) >> 8,
                               (val * gw + (0xFF - val) * qGreen(*data)) >> 8,
                               (val * bw + (0xFF - val) * qBlue(*data)) >> 8,
                               qAlpha(*data));
+            }
             ++data;
         }
     } else {
         while (data != end) {
-            if (qGray(*data) <= medium)
+            if (qGray(*data) <= medium) {
                 *data = qRgba((val * rb + (0xFF - val) * qRed(*data)) >> 8,
                               (val * gb + (0xFF - val) * qGreen(*data)) >> 8,
                               (val * bb + (0xFF - val) * qBlue(*data)) >> 8,
                               qAlpha(*data));
-            else
+            } else {
                 *data = qRgba((val * rw + (0xFF - val) * qRed(*data)) >> 8,
                               (val * gw + (0xFF - val) * qGreen(*data)) >> 8,
                               (val * bw + (0xFF - val) * qBlue(*data)) >> 8,
                               qAlpha(*data));
+            }
             ++data;
         }
     }
@@ -467,13 +459,14 @@ void KIconEffect::deSaturate(QImage &img, float value)
     QRgb *end = data + ii.pixels;
 
     QColor color;
-    int h, s, v;
+    int h;
+    int s;
+    int v;
     while (data != end) {
         color.setRgb(*data);
         color.getHsv(&h, &s, &v);
         color.setHsv(h, (int)(s * (1.0 - value) + 0.5), v);
-        *data = qRgba(color.red(), color.green(), color.blue(),
-                      qAlpha(*data));
+        *data = qRgba(color.red(), color.green(), color.blue(), qAlpha(*data));
         ++data;
     }
 }
@@ -486,12 +479,9 @@ void KIconEffect::toGamma(QImage &img, float value)
 
     float gamma = 1 / (2 * value + 0.5);
     while (data != end) {
-        *data = qRgba(static_cast<unsigned char>
-                      (pow(static_cast<float>(qRed(*data)) / 255, gamma) * 255),
-                      static_cast<unsigned char>
-                      (pow(static_cast<float>(qGreen(*data)) / 255, gamma) * 255),
-                      static_cast<unsigned char>
-                      (pow(static_cast<float>(qBlue(*data)) / 255, gamma) * 255),
+        *data = qRgba(static_cast<unsigned char>(pow(static_cast<float>(qRed(*data)) / 255, gamma) * 255),
+                      static_cast<unsigned char>(pow(static_cast<float>(qGreen(*data)) / 255, gamma) * 255),
+                      static_cast<unsigned char>(pow(static_cast<float>(qBlue(*data)) / 255, gamma) * 255),
                       qAlpha(*data));
         ++data;
     }
@@ -501,9 +491,9 @@ void KIconEffect::semiTransparent(QImage &img)
 {
     if (img.depth() == 32) {
         if (img.format() == QImage::Format_ARGB32_Premultiplied) {
-            img = img.convertToFormat(QImage::Format_ARGB32);
+            img.convertTo(QImage::Format_ARGB32);
         }
-        int width  = img.width();
+        int width = img.width();
         int height = img.height();
 
         unsigned char *line;
@@ -520,7 +510,7 @@ void KIconEffect::semiTransparent(QImage &img)
         }
     } else if (img.depth() == 8) {
         // not running on 8 bit, we can safely install a new colorTable
-        QVector<QRgb> colorTable = img.colorTable();
+        QList<QRgb> colorTable = img.colorTable();
         for (int i = 0; i < colorTable.size(); ++i) {
             colorTable[i] = (colorTable[i] & 0x00ffffff) | ((colorTable[i] & 0xfe000000) >> 1);
         }
@@ -600,9 +590,11 @@ QImage KIconEffect::doublePixels(const QImage &src) const
         return QImage();
     }
 
-    int x, y;
+    int x;
+    int y;
     if (src.depth() == 32) {
-        QRgb *l1, *l2;
+        QRgb *l1;
+        QRgb *l2;
         for (y = 0; y < h; ++y) {
             l1 = (QRgb *)src.scanLine(y);
             l2 = (QRgb *)dst.scanLine(y * 2);
@@ -634,7 +626,8 @@ QImage KIconEffect::doublePixels(const QImage &src) const
 void KIconEffect::overlay(QImage &src, QImage &overlay)
 {
     if (src.depth() != overlay.depth()) {
-        qWarning() << "Image depth src (" << src.depth() << ") != overlay " << "(" << overlay.depth() << ")!";
+        qWarning() << "Image depth src (" << src.depth() << ") != overlay "
+                   << "(" << overlay.depth() << ")!";
         return;
     }
     if (src.size() != overlay.size()) {
@@ -642,17 +635,18 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
         return;
     }
     if (src.format() == QImage::Format_ARGB32_Premultiplied) {
-        src = src.convertToFormat(QImage::Format_ARGB32);
+        src.convertTo(QImage::Format_ARGB32);
     }
 
     if (overlay.format() == QImage::Format_RGB32) {
         qWarning() << "Overlay doesn't have alpha buffer!";
         return;
     } else if (overlay.format() == QImage::Format_ARGB32_Premultiplied) {
-        overlay = overlay.convertToFormat(QImage::Format_ARGB32);
+        overlay.convertTo(QImage::Format_ARGB32);
     }
 
-    int i, j;
+    int i;
+    int j;
 
     // We don't do 1 bpp
 
@@ -690,7 +684,8 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
         }
 
         // Overwrite nontransparent pixels.
-        unsigned char *oline, *sline;
+        unsigned char *oline;
+        unsigned char *sline;
         for (i = 0; i < src.height(); ++i) {
             oline = overlay.scanLine(i);
             sline = src.scanLine(i);
@@ -705,9 +700,16 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
     // Overlay at 32 bpp does use alpha blending
 
     if (src.depth() == 32) {
-        QRgb *oline, *sline;
-        int r1, g1, b1, a1;
-        int r2, g2, b2, a2;
+        QRgb *oline;
+        QRgb *sline;
+        int r1;
+        int g1;
+        int b1;
+        int a1;
+        int r2;
+        int g2;
+        int b2;
+        int a2;
 
         for (i = 0; i < src.height(); ++i) {
             oline = (QRgb *)overlay.scanLine(i);
@@ -734,4 +736,3 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
         }
     }
 }
-
