@@ -16,7 +16,6 @@
 // kdecore
 #include <KConfigGroup>
 #include <KSharedConfig>
-#include <kshareddatacache.h>
 #ifdef QT_DBUS_LIB
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -31,9 +30,6 @@
 #include "kiconeffect.h"
 #include "kicontheme.h"
 
-// kwidgetsaddons
-#include <KPixmapSequence>
-
 #include <KColorScheme>
 #include <KCompressionDevice>
 
@@ -197,13 +193,6 @@ void KIconLoaderGlobalData::parseGenericIconsFiles(const QString &fileName)
     QFile file(fileName);
     if (file.open(QIODevice::ReadOnly)) {
         QTextStream stream(&file);
-        // In Qt6 the encoding is UTF-8 by default, so it should work for icon file names;
-        // I think this code had "ISO 8859-1" (i.e. Latin-1) as an optimization, but file
-        // names on Linux are UTF-8 by default, so this would be more robust.
-        // Note that in Qt6 we can have the same behaviour by using QTextStream::setEncoding().
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec("ISO 8859-1");
-#endif
         while (!stream.atEnd()) {
             const QString line = stream.readLine();
             if (line.isEmpty() || line[0] == QLatin1Char('#')) {
@@ -254,9 +243,7 @@ void KIconLoaderPrivate::clear()
     deleted when the elements of d->links are deleted */
     qDeleteAll(links);
     delete[] mpGroups;
-    delete mIconCache;
     mpGroups = nullptr;
-    mIconCache = nullptr;
     mPixmapCache.clear();
     m_appname.clear();
     searchPaths.clear();
@@ -379,7 +366,6 @@ KIconLoader::KIconLoader(const QString &appname, const QStringList &extraSearchP
 
 void KIconLoader::reconfigure(const QString &_appname, const QStringList &extraSearchPaths)
 {
-    d->mIconCache->clear();
     d->clear();
     d->init(_appname, extraSearchPaths);
 }
@@ -394,17 +380,13 @@ void KIconLoaderPrivate::init(const QString &_appname, const QStringList &extraS
 
     m_appname = !_appname.isEmpty() ? _appname : QCoreApplication::applicationName();
 
-    // Initialize icon cache
-    mIconCache = new KSharedDataCache(QStringLiteral("icon-cache"), 10 * 1024 * 1024);
-    // Cost here is number of pixels, not size. So this is actually a bit
-    // smaller.
+    // Cost here is number of pixels
     mPixmapCache.setMaxCost(10 * 1024 * 1024);
 
     // These have to match the order in kiconloader.h
     static const char *const groups[] = {"Desktop", "Toolbar", "MainToolbar", "Small", "Panel", "Dialog", nullptr};
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    // loading config and default sizes
+    // load default sizes
     initIconThemes();
     KIconTheme *defaultSizesTheme = links.empty() ? nullptr : links.first()->theme;
     mpGroups = new KIconGroup[static_cast<int>(KIconLoader::LastGroup)];
@@ -413,10 +395,7 @@ void KIconLoaderPrivate::init(const QString &_appname, const QStringList &extraS
             break;
         }
 
-        KConfigGroup cg(config, QLatin1String(groups[i]) + QStringLiteral("Icons"));
-        mpGroups[i].size = cg.readEntry("Size", 0);
-
-        if (!mpGroups[i].size && defaultSizesTheme) {
+        if (defaultSizesTheme) {
             mpGroups[i].size = defaultSizesTheme->defaultSize(i);
         }
     }
@@ -707,6 +686,7 @@ QImage KIconLoaderPrivate::createIconImage(const QString &path, const QSize &siz
     if (q->theme() && q->theme()->followsColorScheme() && (path.endsWith(QLatin1String("svg")) || path.endsWith(QLatin1String("svgz")))) {
         buffer.setData(processSvg(path, state, colors));
         reader.setDevice(&buffer);
+        reader.setFormat("svg");
     } else {
         reader.setFileName(path);
     }
@@ -738,24 +718,6 @@ void KIconLoaderPrivate::insertCachedPixmapWithPath(const QString &key, const QP
     // the fact that whatever icon led to us getting a null pixmap doesn't
     // exist.
 
-    QBuffer output;
-    output.open(QIODevice::WriteOnly);
-
-    QDataStream outputStream(&output);
-    outputStream.setVersion(QDataStream::Qt_4_6);
-
-    outputStream << path;
-
-    // Convert the QPixmap to PNG. This is actually done by Qt's own operator.
-    outputStream << data;
-
-    output.close();
-
-    // The byte array contained in the QBuffer is what we want in the cache.
-    mIconCache->insert(key, output.buffer());
-
-    // Also insert the object into our process-local cache for even more
-    // speed.
     PixmapWithPath *pixmapPath = new PixmapWithPath;
     pixmapPath->pixmap = data;
     pixmapPath->path = path;
@@ -771,47 +733,9 @@ bool KIconLoaderPrivate::findCachedPixmapWithPath(const QString &key, QPixmap &d
     if (pixmapPath) {
         path = pixmapPath->path;
         data = pixmapPath->pixmap;
-
         return true;
     }
 
-    // Otherwise try to find it in our shared memory cache since that will
-    // be quicker than the disk, especially for SVGs.
-    QByteArray result;
-
-    if (!mIconCache->find(key, &result) || result.isEmpty()) {
-        return false;
-    }
-
-    QBuffer buffer;
-    buffer.setBuffer(&result);
-    buffer.open(QIODevice::ReadOnly);
-
-    QDataStream inputStream(&buffer);
-    inputStream.setVersion(QDataStream::Qt_4_6);
-
-    QString tempPath;
-    inputStream >> tempPath;
-
-    if (inputStream.status() == QDataStream::Ok) {
-        QPixmap tempPixmap;
-        inputStream >> tempPixmap;
-
-        if (inputStream.status() == QDataStream::Ok) {
-            data = tempPixmap;
-            path = tempPath;
-
-            // Since we're here we didn't have a QPixmap cache entry, add one now.
-            PixmapWithPath *newPixmapWithPath = new PixmapWithPath;
-            newPixmapWithPath->pixmap = data;
-            newPixmapWithPath->path = path;
-
-            mPixmapCache.insert(key, newPixmapWithPath, data.width() * data.height() + 1);
-
-            return true;
-        }
-    }
-
     return false;
 }
 
@@ -1213,7 +1137,7 @@ QPixmap KIconLoader::loadScaledIcon(const QString &_name,
         }
     }
 
-    pix = QPixmap::fromImage(img);
+    pix = QPixmap::fromImage(std::move(img));
 
     // TODO: If we make a loadIcon that returns the image we can convert
     // drawOverlays to use the image instead of pixmaps as well so we don't
@@ -1235,11 +1159,6 @@ QPixmap KIconLoader::loadScaledIcon(const QString &_name,
     return pix;
 }
 
-KPixmapSequence KIconLoader::loadPixmapSequence(const QString &xdgIconName, int size) const
-{
-    return KPixmapSequence(iconPath(xdgIconName, -size), size);
-}
-
 QMovie *KIconLoader::loadMovie(const QString &name, KIconLoader::Group group, int size, QObject *parent) const
 {
     QString file = moviePath(name, group, size);
@@ -1345,11 +1264,7 @@ QStringList KIconLoader::loadAnimated(const QString &name, KIconLoader::Group gr
 
     const auto entryList = dir.entryList();
     for (const QString &entry : entryList) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const QStringView chunk = QStringView(entry).left(4);
-#else
-        const QStringRef chunk = entry.leftRef(4);
-#endif
         if (!chunk.toUInt()) {
             continue;
         }
@@ -1487,126 +1402,6 @@ KIconEffect *KIconLoader::iconEffect() const
     return &d->mpEffect;
 }
 
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 82)
-bool KIconLoader::alphaBlending(KIconLoader::Group group) const
-{
-    if (!d->mpGroups) {
-        return false;
-    }
-
-    if (group < 0 || group >= KIconLoader::LastGroup) {
-        qCDebug(KICONTHEMES) << "Invalid icon group:" << group << ", should be one of KIconLoader::Group";
-        return false;
-    }
-    return true;
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon KIconLoader::loadIconSet(const QString &name, KIconLoader::Group g, int s, bool canReturnNull)
-{
-    QIcon iconset;
-    QPixmap tmp = loadIcon(name, g, s, KIconLoader::ActiveState, QStringList(), nullptr, canReturnNull);
-    iconset.addPixmap(tmp, QIcon::Active, QIcon::On);
-    // we don't use QIconSet's resizing anyway
-    tmp = loadIcon(name, g, s, KIconLoader::DisabledState, QStringList(), nullptr, canReturnNull);
-    iconset.addPixmap(tmp, QIcon::Disabled, QIcon::On);
-    tmp = loadIcon(name, g, s, KIconLoader::DefaultState, QStringList(), nullptr, canReturnNull);
-    iconset.addPixmap(tmp, QIcon::Normal, QIcon::On);
-    return iconset;
-}
-#endif
-
-// Easy access functions
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 63)
-QPixmap DesktopIcon(const QString &name, int force_size, int state, const QStringList &overlays)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIcon(name, KIconLoader::Desktop, force_size, state, overlays);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon DesktopIconSet(const QString &name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::Desktop, force_size);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 63)
-QPixmap BarIcon(const QString &name, int force_size, int state, const QStringList &overlays)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIcon(name, KIconLoader::Toolbar, force_size, state, overlays);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon BarIconSet(const QString &name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::Toolbar, force_size);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 63)
-QPixmap SmallIcon(const QString &name, int force_size, int state, const QStringList &overlays)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIcon(name, KIconLoader::Small, force_size, state, overlays);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon SmallIconSet(const QString &name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::Small, force_size);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 63)
-QPixmap MainBarIcon(const QString &name, int force_size, int state, const QStringList &overlays)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIcon(name, KIconLoader::MainToolbar, force_size, state, overlays);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon MainBarIconSet(const QString &name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::MainToolbar, force_size);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 65)
-QPixmap UserIcon(const QString &name, int state, const QStringList &overlays)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIcon(name, KIconLoader::User, 0, state, overlays);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 0)
-QIcon UserIconSet(const QString &name)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::User);
-}
-#endif
-
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 66)
-int IconSize(KIconLoader::Group group)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->currentSize(group);
-}
-#endif
-
 QPixmap KIconLoader::unknown()
 {
     QPixmap pix;
@@ -1692,4 +1487,4 @@ QIcon KDE::icon(const QString &iconName, const KIconColors &colors, KIconLoader
 }
 
 #include "kiconloader.moc"
-#include "moc_kiconloader.moc"
+#include "moc_kiconloader.cpp"
